# Gibme - CTF and Pentester Sidekick

![Gibme Showcase](/imgs/gibme.gif)

## Features

- Binaries from GTFOBins
- Executables from LOLBAS
- Reverse Shell Generator
- tldr project integration
- CVE Search with POCs from github. Front-end of this is here at [CVE-Search](https://foreztgump.github.io/cve_search/)
- Cheat Sheet feature is coming soon

## Getting Started

Installation:
```sh
pipx install gibme
pipx ensurepath
```

Upgrade:
```sh
pipx upgrade gibme
```

Development:

```sh
git clone https://github.com/foreztgump/gibme.git
cd gibme
pip install -r requirements.txt
```

**To select any texts in gibme hold shift**

## Join the Effort

- Got a fix for something? Awesome! Open a pull request and we'll review it together.
- Spotted a bug? Let me know! Report it and I'll get to squashing.
- Any thoughts or ideas? Open an issue, I'm all ears!

## Upcoming Tasks
- Code refactoring is on the horizon!
- Need cleanup as well

## License

This project is licensed under the terms of the MIT License. 

MIT License

Copyright (c) [2023] [foreztgump]

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

## Resources - Credits - Thank you!

- [reverse-shell-generator](https://github.com/0dayCTF/reverse-shell-generator)
- [gtfo](https://github.com/mzfr/gtfo)
- [LOLBAS](https://github.com/LOLBAS-Project/LOLBAS)
- [GTFO](https://github.com/GTFOBins/GTFOBins.github.io)
- [PayloadsAllTheThings](https://github.com/swisskyrepo/PayloadsAllTheThings/)
- [RapidFuzz](https://github.com/maxbachmann/RapidFuzz/)
- [rich](https://github.com/Textualize/rich)
- [httpx](https://github.com/encode/httpx)
- [tldr](https://github.com/tldr-pages/tldr/tree/main)
- [trickest](https://github.com/trickest/cve/)
